\# FastTGBot



Create Telegram bot in 3 lines!



\## Install

pip install fasttgbot



\## Example

from fasttgbot import FastTGBot, ifm, snd, btn



bot = FastTGBot("YOUR\_TOKEN")

ifm("/start", snd("Hello!"))

btn("Button", snd("Clicked!"))

bot.run()

